# encoding: INFORMIXV6ALS
# This file is encoded in INFORMIX V6 ALS.
die "This file is not encoded in INFORMIX V6 ALS.\n" if q{‚ } ne "\x82\xa0";

use strict;
use INFORMIXV6ALS;
print "1..56\n";

my $__FILE__ = __FILE__;

if ('A' =~ qr/A/) {
    print qq{ok - 1 'A' =~ qr/A/ $^X $__FILE__\n};
}
else {
    print qq{not ok - 1 'A' =~ qr/A/ $^X $__FILE__\n};
}

if ('A' =~ qr/A/b) {
    print qq{ok - 2 'A' =~ qr/A/b $^X $__FILE__\n};
}
else {
    print qq{not ok - 2 'A' =~ qr/A/b $^X $__FILE__\n};
}

if ('A' =~ qr/a/i) {
    print qq{ok - 3 'A' =~ qr/a/i $^X $__FILE__\n};
}
else {
    print qq{not ok - 3 'A' =~ qr/a/i $^X $__FILE__\n};
}

if ('A' =~ qr/a/ib) {
    print qq{ok - 4 'A' =~ qr/a/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 4 'A' =~ qr/a/ib $^X $__FILE__\n};
}

if ('a' =~ qr/A/) {
    print qq{not ok - 5 'a' =~ qr/A/ $^X $__FILE__\n};
}
else {
    print qq{ok - 5 'a' =~ qr/A/ $^X $__FILE__\n};
}

if ('a' =~ qr/A/b) {
    print qq{not ok - 6 'a' =~ qr/A/b $^X $__FILE__\n};
}
else {
    print qq{ok - 6 'a' =~ qr/A/b $^X $__FILE__\n};
}

if ('a' =~ qr/a/i) {
    print qq{ok - 7 'a' =~ qr/a/i $^X $__FILE__\n};
}
else {
    print qq{not ok - 7 'a' =~ qr/a/i $^X $__FILE__\n};
}

if ('a' =~ qr/a/ib) {
    print qq{ok - 8 'a' =~ qr/a/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 8 'a' =~ qr/a/ib $^X $__FILE__\n};
}

if ('A' =~ qr/ƒA/) {
    print qq{not ok - 9 'A' =~ qr/ƒA/ $^X $__FILE__\n};
}
else {
    print qq{ok - 9 'A' =~ qr/ƒA/ $^X $__FILE__\n};
}

if ('A' =~ qr/ƒA/b) {
    print qq{not ok - 10 'A' =~ qr/ƒA/b $^X $__FILE__\n};
}
else {
    print qq{ok - 10 'A' =~ qr/ƒA/b $^X $__FILE__\n};
}

if ('A' =~ qr/ƒA/i) {
    print qq{not ok - 11 'A' =~ qr/ƒA/i $^X $__FILE__\n};
}
else {
    print qq{ok - 11 'A' =~ qr/ƒA/i $^X $__FILE__\n};
}

if ('A' =~ qr/ƒA/ib) {
    print qq{not ok - 12 'A' =~ qr/ƒA/ib $^X $__FILE__\n};
}
else {
    print qq{ok - 12 'A' =~ qr/ƒA/ib $^X $__FILE__\n};
}

if ('A' =~ qr/ƒa/) {
    print qq{not ok - 13 'A' =~ qr/ƒa/ $^X $__FILE__\n};
}
else {
    print qq{ok - 13 'A' =~ qr/ƒa/ $^X $__FILE__\n};
}

if ('A' =~ qr/ƒa/b) {
    print qq{not ok - 14 'A' =~ qr/ƒa/b $^X $__FILE__\n};
}
else {
    print qq{ok - 14 'A' =~ qr/ƒa/b $^X $__FILE__\n};
}

if ('A' =~ qr/ƒa/i) {
    print qq{not ok - 15 'A' =~ qr/ƒa/i $^X $__FILE__\n};
}
else {
    print qq{ok - 15 'A' =~ qr/ƒa/i $^X $__FILE__\n};
}

if ('A' =~ qr/ƒa/ib) {
    print qq{not ok - 16 'A' =~ qr/ƒa/ib $^X $__FILE__\n};
}
else {
    print qq{ok - 16 'A' =~ qr/ƒa/ib $^X $__FILE__\n};
}

if ('a' =~ qr/ƒA/) {
    print qq{not ok - 17 'a' =~ qr/ƒA/ $^X $__FILE__\n};
}
else {
    print qq{ok - 17 'a' =~ qr/ƒA/ $^X $__FILE__\n};
}

if ('a' =~ qr/ƒA/b) {
    print qq{not ok - 18 'a' =~ qr/ƒA/b $^X $__FILE__\n};
}
else {
    print qq{ok - 18 'a' =~ qr/ƒA/b $^X $__FILE__\n};
}

if ('a' =~ qr/ƒA/i) {
    print qq{not ok - 19 'a' =~ qr/ƒA/i $^X $__FILE__\n};
}
else {
    print qq{ok - 19 'a' =~ qr/ƒA/i $^X $__FILE__\n};
}

if ('a' =~ qr/ƒA/ib) {
    print qq{not ok - 20 'a' =~ qr/ƒA/ib $^X $__FILE__\n};
}
else {
    print qq{ok - 20 'a' =~ qr/ƒA/ib $^X $__FILE__\n};
}

if ('a' =~ qr/ƒa/) {
    print qq{not ok - 21 'a' =~ qr/ƒa/ $^X $__FILE__\n};
}
else {
    print qq{ok - 21 'a' =~ qr/ƒa/ $^X $__FILE__\n};
}

if ('a' =~ qr/ƒa/b) {
    print qq{not ok - 22 'a' =~ qr/ƒa/b $^X $__FILE__\n};
}
else {
    print qq{ok - 22 'a' =~ qr/ƒa/b $^X $__FILE__\n};
}

if ('a' =~ qr/ƒa/i) {
    print qq{not ok - 23 'a' =~ qr/ƒa/i $^X $__FILE__\n};
}
else {
    print qq{ok - 23 'a' =~ qr/ƒa/i $^X $__FILE__\n};
}

if ('a' =~ qr/ƒa/ib) {
    print qq{not ok - 24 'a' =~ qr/ƒa/ib $^X $__FILE__\n};
}
else {
    print qq{ok - 24 'a' =~ qr/ƒa/ib $^X $__FILE__\n};
}

if ('ƒA' =~ qr/A/) {
    print qq{not ok - 25 'ƒA' =~ qr/A/ $^X $__FILE__\n};
}
else {
    print qq{ok - 25 'ƒA' =~ qr/A/ $^X $__FILE__\n};
}

if ('ƒA' =~ qr/A/b) {
    print qq{ok - 26 'ƒA' =~ qr/A/b $^X $__FILE__\n};
}
else {
    print qq{not ok - 26 'ƒA' =~ qr/A/b $^X $__FILE__\n};
}

if ('ƒA' =~ qr/A/i) {
    print qq{not ok - 27 'ƒA' =~ qr/A/i $^X $__FILE__\n};
}
else {
    print qq{ok - 27 'ƒA' =~ qr/A/i $^X $__FILE__\n};
}

if ('ƒA' =~ qr/A/ib) {
    print qq{ok - 28 'ƒA' =~ qr/A/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 28 'ƒA' =~ qr/A/ib $^X $__FILE__\n};
}

if ('ƒA' =~ qr/a/) {
    print qq{not ok - 29 'ƒA' =~ qr/a/ $^X $__FILE__\n};
}
else {
    print qq{ok - 29 'ƒA' =~ qr/a/ $^X $__FILE__\n};
}

if ('ƒA' =~ qr/a/b) {
    print qq{not ok - 30 'ƒA' =~ qr/a/b $^X $__FILE__\n};
}
else {
    print qq{ok - 30 'ƒA' =~ qr/a/b $^X $__FILE__\n};
}

if ('ƒA' =~ qr/a/i) {
    print qq{not ok - 31 'ƒA' =~ qr/a/i $^X $__FILE__\n};
}
else {
    print qq{ok - 31 'ƒA' =~ qr/a/i $^X $__FILE__\n};
}

if ('ƒA' =~ qr/a/ib) {
    print qq{ok - 32 'ƒA' =~ qr/a/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 32 'ƒA' =~ qr/a/ib $^X $__FILE__\n};
}

if ('ƒa' =~ qr/A/) {
    print qq{not ok - 33 'ƒa' =~ qr/A/ $^X $__FILE__\n};
}
else {
    print qq{ok - 33 'ƒa' =~ qr/A/ $^X $__FILE__\n};
}

if ('ƒa' =~ qr/A/b) {
    print qq{not ok - 34 'ƒa' =~ qr/A/b $^X $__FILE__\n};
}
else {
    print qq{ok - 34 'ƒa' =~ qr/A/b $^X $__FILE__\n};
}

if ('ƒa' =~ qr/A/i) {
    print qq{not ok - 35 'ƒa' =~ qr/A/i $^X $__FILE__\n};
}
else {
    print qq{ok - 35 'ƒa' =~ qr/A/i $^X $__FILE__\n};
}

if ('ƒa' =~ qr/A/ib) {
    print qq{ok - 36 'ƒa' =~ qr/A/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 36 'ƒa' =~ qr/A/ib $^X $__FILE__\n};
}

if ('ƒa' =~ qr/a/) {
    print qq{not ok - 37 'ƒa' =~ qr/a/ $^X $__FILE__\n};
}
else {
    print qq{ok - 37 'ƒa' =~ qr/a/ $^X $__FILE__\n};
}

if ('ƒa' =~ qr/a/b) {
    print qq{ok - 38 'ƒa' =~ qr/a/b $^X $__FILE__\n};
}
else {
    print qq{not ok - 38 'ƒa' =~ qr/a/b $^X $__FILE__\n};
}

if ('ƒa' =~ qr/a/i) {
    print qq{not ok - 39 'ƒa' =~ qr/a/i $^X $__FILE__\n};
}
else {
    print qq{ok - 39 'ƒa' =~ qr/a/i $^X $__FILE__\n};
}

if ('ƒa' =~ qr/a/ib) {
    print qq{ok - 40 'ƒa' =~ qr/a/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 40 'ƒa' =~ qr/a/ib $^X $__FILE__\n};
}

if ('ƒƒA' =~ qr/ƒA/) {
    print qq{not ok - 41 'ƒƒA' =~ qr/ƒA/ $^X $__FILE__\n};
}
else {
    print qq{ok - 41 'ƒƒA' =~ qr/ƒA/ $^X $__FILE__\n};
}

if ('ƒƒA' =~ qr/ƒA/b) {
    print qq{ok - 42 'ƒƒA' =~ qr/ƒA/b $^X $__FILE__\n};
}
else {
    print qq{not ok - 42 'ƒƒA' =~ qr/ƒA/b $^X $__FILE__\n};
}

if ('ƒƒA' =~ qr/ƒA/i) {
    print qq{not ok - 43 'ƒƒA' =~ qr/ƒA/i $^X $__FILE__\n};
}
else {
    print qq{ok - 43 'ƒƒA' =~ qr/ƒA/i $^X $__FILE__\n};
}

if ('ƒƒA' =~ qr/ƒA/ib) {
    print qq{ok - 44 'ƒƒA' =~ qr/ƒA/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 44 'ƒƒA' =~ qr/ƒA/ib $^X $__FILE__\n};
}

if ('ƒƒA' =~ qr/ƒa/) {
    print qq{not ok - 45 'ƒƒA' =~ qr/ƒa/ $^X $__FILE__\n};
}
else {
    print qq{ok - 45 'ƒƒA' =~ qr/ƒa/ $^X $__FILE__\n};
}

if ('ƒƒA' =~ qr/ƒa/b) {
    print qq{not ok - 46 'ƒƒA' =~ qr/ƒa/b $^X $__FILE__\n};
}
else {
    print qq{ok - 46 'ƒƒA' =~ qr/ƒa/b $^X $__FILE__\n};
}

if ('ƒƒA' =~ qr/ƒa/i) {
    print qq{not ok - 47 'ƒƒA' =~ qr/ƒa/i $^X $__FILE__\n};
}
else {
    print qq{ok - 47 'ƒƒA' =~ qr/ƒa/i $^X $__FILE__\n};
}

if ('ƒƒA' =~ qr/ƒa/ib) {
    print qq{ok - 48 'ƒƒA' =~ qr/ƒa/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 48 'ƒƒA' =~ qr/ƒa/ib $^X $__FILE__\n};
}

if ('ƒƒa' =~ qr/ƒA/) {
    print qq{not ok - 49 'ƒƒa' =~ qr/ƒA/ $^X $__FILE__\n};
}
else {
    print qq{ok - 49 'ƒƒa' =~ qr/ƒA/ $^X $__FILE__\n};
}

if ('ƒƒa' =~ qr/ƒA/b) {
    print qq{not ok - 50 'ƒƒa' =~ qr/ƒA/b $^X $__FILE__\n};
}
else {
    print qq{ok - 50 'ƒƒa' =~ qr/ƒA/b $^X $__FILE__\n};
}

if ('ƒƒa' =~ qr/ƒA/i) {
    print qq{not ok - 51 'ƒƒa' =~ qr/ƒA/i $^X $__FILE__\n};
}
else {
    print qq{ok - 51 'ƒƒa' =~ qr/ƒA/i $^X $__FILE__\n};
}

if ('ƒƒa' =~ qr/ƒA/ib) {
    print qq{ok - 52 'ƒƒa' =~ qr/ƒA/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 52 'ƒƒa' =~ qr/ƒA/ib $^X $__FILE__\n};
}

if ('ƒƒa' =~ qr/ƒa/) {
    print qq{not ok - 53 'ƒƒa' =~ qr/ƒa/ $^X $__FILE__\n};
}
else {
    print qq{ok - 53 'ƒƒa' =~ qr/ƒa/ $^X $__FILE__\n};
}

if ('ƒƒa' =~ qr/ƒa/b) {
    print qq{ok - 54 'ƒƒa' =~ qr/ƒa/b $^X $__FILE__\n};
}
else {
    print qq{not ok - 54 'ƒƒa' =~ qr/ƒa/b $^X $__FILE__\n};
}

if ('ƒƒa' =~ qr/ƒa/i) {
    print qq{not ok - 55 'ƒƒa' =~ qr/ƒa/i $^X $__FILE__\n};
}
else {
    print qq{ok - 55 'ƒƒa' =~ qr/ƒa/i $^X $__FILE__\n};
}

if ('ƒƒa' =~ qr/ƒa/ib) {
    print qq{ok - 56 'ƒƒa' =~ qr/ƒa/ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 56 'ƒƒa' =~ qr/ƒa/ib $^X $__FILE__\n};
}

__END__

